@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixgtk.c :
  * Main functions of the mix gtk front-end
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-05-04 01:33:02 jao"
+ *  Last change: Time-stamp: "2001-05-20 18:03:05 jao"
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -95,21 +95,21 @@ mixgtk_init (int argc, char *argv[])
       return FALSE;
     }
 
-  if (!mixgtk_input_init ())
-    {
-      g_error ("Unable to initialise application (word input widgets)\n");
-      return FALSE;
-    }
-
-  if (!mixgtk_fontsel_init () || !mixgtk_colorsel_init ())
-    {
-      g_error ("Unable to initialise application (customization widgets)\n");
-      return FALSE;
-    }
-    
+  mixgtk_fontsel_load_defaults ();
+  
   return TRUE;
 }
 
+/* main loop */
+void
+mixgtk_main (void)
+{
+  gtk_widget_show (mixgtk_widget_factory_get_dialog (MIXGTK_MAIN));
+  mixgtk_mixvm_update_vm_widgets ();
+
+  gtk_main ();
+}
+
 /* clean up */
 void
 mixgtk_release (void) 
