@@ -33,9 +33,11 @@ static file_callback_t callback_ = NULL;
 static void
 on_file_ok_ (GtkWidget *w, gpointer fs)
 {
-  const gchar *file = gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs));
+  gchar *file = g_strdup
+	  (gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)));
   gtk_widget_destroy (GTK_WIDGET (fs));
   if (callback_) callback_ (file);
+  g_free (file);
 }
 
 static void
