@@ -30,9 +30,58 @@
 #include "mixgtk_mixal.h"
 
 
+#define MIXAL_TAB_POS_ 2
+
 static mix_vm_t *vm_;
 static GtkCList *clist_;
 static gulong lineno_;
+static GtkStatusbar *status_;
+static gint status_context_;
+static GPtrArray *tips_text_ = NULL;
+
+static GtkWidget *symbols_dlg_ = NULL;
+static GtkWidget *symbols_clist_ = NULL;
+static const gchar *SYMBOLS_CLIST_NAME_ = "symbols_clist";
+
+static void
+init_symbols_ (void) 
+{
+  symbols_dlg_ = mixgtk_widget_factory_get_dialog (MIXGTK_SYMBOLS_DIALOG);
+  g_assert (symbols_dlg_);
+  symbols_clist_ = mixgtk_widget_factory_get_child_by_name
+    (MIXGTK_SYMBOLS_DIALOG, SYMBOLS_CLIST_NAME_);
+  g_assert (symbols_clist_);
+  gtk_clist_set_sort_type (GTK_CLIST (symbols_clist_), GTK_SORT_ASCENDING);
+  gtk_clist_set_auto_sort (GTK_CLIST (symbols_clist_), TRUE);
+}
+
+static void
+insert_symbol_ (gpointer symbol, gpointer value, gpointer list)
+{
+  enum {DEC_SIZE = 25, WORD_SIZE = 20};
+  static gchar DEC[DEC_SIZE], WORD[WORD_SIZE];
+  
+  gchar *text[] = {(gchar *)symbol, DEC, WORD};
+  mix_word_t w = (mix_word_t)GPOINTER_TO_INT (value);
+  snprintf (DEC, DEC_SIZE, "%s%ld",
+	    mix_word_is_negative (w)? "-" : "+",
+	    mix_word_magnitude (w));
+  mix_word_print_to_buffer (w, WORD);
+  gtk_clist_append ((GtkCList *)list, text);
+}
+
+static void
+fill_symbols_ (const mix_symbol_table_t *table)
+{
+  if (symbols_clist_)
+    gtk_clist_clear (GTK_CLIST (symbols_clist_));
+  else
+    init_symbols_ ();
+  
+  mix_symbol_table_foreach (((mix_symbol_table_t *)table),
+			    insert_symbol_, (gpointer)symbols_clist_);
+}
+
 static GdkColor colors_[3][2];
 static GdkColormap *colormap_ = NULL;
 static const char* default_colors_[3][2] = {
@@ -65,7 +114,8 @@ color_to_string_ (const GdkColor *color)
 {
   enum {LEN = 100};
   static gchar buffer[LEN];
-  g_snprintf (buffer, LEN, "%hd %hd %hd", color->red, color->green, color->blue);
+  g_snprintf (buffer, LEN, "%hd %hd %hd",
+	      color->red, color->green, color->blue);
   return buffer;
 }
 
@@ -86,7 +136,11 @@ mixgtk_mixal_init (mix_vm_t *vm)
   vm_ = vm;
   clist_ = GTK_CLIST (mixgtk_widget_factory_get (MIXGTK_WIDGET_MIXAL));
   g_return_val_if_fail (clist_ != NULL, FALSE);
-
+  
+  status_ = GTK_STATUSBAR (mixgtk_widget_factory_get (MIXGTK_WIDGET_STATUSBAR));
+  g_return_val_if_fail (status_ != NULL, FALSE);
+  status_context_ = gtk_statusbar_get_context_id (status_, "MIXAL status");
+  
   /* allocate colors */
   colormap_ = gtk_widget_get_colormap (GTK_WIDGET (clist_));
   for (i = 0; i < 3; ++i)
@@ -134,6 +188,42 @@ mixgtk_mixal_get_color (mixal_line_t line, mixal_line_zone_t zone)
 }
 
 /* load the corresponding mixal file */
+static void
+update_tips_ (const mix_symbol_table_t *table,
+	      const gchar *line)
+{
+  enum {SIZE = 256};
+  static gchar BUFFER[256];
+  static const gchar *DELIMITERS = " /+*=-()\t,:\n";
+  if (line)
+    {
+      guint k = 0;
+      gchar *tip = g_strdup ("");
+      gchar *new_tip;
+      gchar **tokens;
+      gchar *text = g_strdup (line);
+      text = g_strdelimit (text, DELIMITERS, ' ');
+      tokens = g_strsplit (g_strstrip (text), " ", -1);
+      while (tokens[k])
+	{
+	  if (mix_symbol_table_is_defined (table, tokens[k]))
+	    {
+	      mix_word_t val = mix_symbol_table_value (table, tokens[k]);
+	      snprintf (BUFFER, SIZE, "[ %s = %s%ld ]", tokens[k],
+			mix_word_is_negative (val)? "-" : "+",
+			mix_word_magnitude (val));
+	      new_tip = g_strconcat (tip, " ", BUFFER, NULL);
+	      g_free (tip);
+	      tip = new_tip;
+	    }
+	  ++k;
+	}
+      g_ptr_array_add (tips_text_, (gpointer)tip);
+      g_strfreev (tokens);
+      g_free (text);
+    }
+}
+
 void
 mixgtk_mixal_load_file (void)
 {
@@ -148,19 +238,21 @@ mixgtk_mixal_load_file (void)
   g_assert (clist_);
   
   gtk_clist_clear (clist_);
-  
   file = mix_vm_get_src_file (vm_);
   if (file != NULL)
     {
       gint k;
       mix_address_t addr;
-
+      const mix_symbol_table_t *table =	mix_vm_get_symbol_table (vm_);
+      
       lineno_ = mix_src_file_get_line_no (file);
-
+      if (tips_text_) g_ptr_array_free (tips_text_, TRUE);
+      tips_text_ = g_ptr_array_new ();
       gtk_clist_freeze (clist_);
       for (k = 0; k < lineno_; ++k)
 	{
 	  const gchar *line = mix_src_file_get_line (file, k + 1);
+	  
 	  snprintf (CONT, CONT_SIZE, "%03d:     %s", k + 1, line);
 	  addr = mix_vm_get_lineno_address (vm_, k + 1);
 	  if (addr != MIX_VM_CELL_NO)
@@ -174,7 +266,10 @@ mixgtk_mixal_load_file (void)
 	  gtk_clist_append (clist_, TEXT);
 	  gtk_clist_set_row_data (clist_, k, GINT_TO_POINTER
 				  (mix_short_magnitude (addr)));
+	  if (table) update_tips_ (table, line);
+	  
 	}
+      if (table) fill_symbols_ (table);
       gtk_clist_append (clist_, NULL_TEXT);
       gtk_clist_set_row_data (clist_, k, GINT_TO_POINTER (MIX_VM_CELL_NO));
       gtk_clist_unselect_row (clist_, 0, 0);
@@ -285,3 +380,43 @@ on_mixal_select_row (GtkWidget *w, gint row, gint col, GdkEventButton *e,
     }
 }
 
+gint
+on_mixal_motion_notify_event (GtkWidget *list, GdkEventMotion *event,
+			      gpointer data)
+{
+  static gint last_row = 0;
+  static guint last_message = 0;
+  gint row = last_row, col = 0;
+  if (gtk_clist_get_selection_info (clist_, event->x, event->y, &row, &col)
+      && row != last_row && tips_text_)
+    {
+      last_row = row;
+      if (last_message)
+	gtk_statusbar_remove (status_, status_context_, last_message);
+      last_message = gtk_statusbar_push
+	(status_, status_context_,
+	 (const gchar *)g_ptr_array_index (tips_text_, row));
+     }
+  return FALSE;
+}
+
+void
+on_symbol_ok_clicked ()
+{
+  gtk_widget_hide (symbols_dlg_);
+}
+
+void
+on_symbols_activate ()
+{
+  if (!symbols_dlg_) init_symbols_ ();
+  gtk_widget_show (symbols_dlg_);
+}
+
+void
+on_notebook_switch_page (GtkNotebook *notebook)
+{
+  gint p = gtk_notebook_get_current_page (notebook);
+  if (p != MIXAL_TAB_POS_) gtk_statusbar_pop (status_, status_context_);
+  if (p == MIXAL_TAB_POS_) mixgtk_mixal_update ();
+}
