@@ -38,7 +38,8 @@ static const gchar * dnames_[] = {
   "colorsel_dialog",
   "fontsel_dialog",
   "devform_dialog",
-  "external_dialog"
+  "external_dialog",
+  "symbols_dialog"
 };
 
 #define DLG_NO_ (sizeof (dnames_) / sizeof(dnames_[0]))
