@@ -726,7 +726,8 @@ cmd_psym_ (mix_vm_cmd_dispatcher_t *dis, const gchar *arg)
     {
       if ( mix_symbol_table_is_defined (table, arg) )
 	{
-	  mix_word_print (mix_symbol_table_value (table, arg), NULL);
+	  mix_word_print_to_file (mix_symbol_table_value (table, arg),
+				  NULL, dis->out);
 	  putc ('\n', dis->out);
 	  result = TRUE;
 	}
@@ -735,7 +736,7 @@ cmd_psym_ (mix_vm_cmd_dispatcher_t *dis, const gchar *arg)
     }
   else
     {
-      mix_symbol_table_print (table, MIX_SYM_ROWS, stdout, TRUE);
+      mix_symbol_table_print (table, MIX_SYM_ROWS, dis->out, TRUE);
       result = TRUE;
     }
       
