@@ -27,7 +27,12 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <getopt.h>
+
+#ifdef HAVE_GETOPT_LONG
+#  include <getopt.h>
+#else
+#  include <lib/getopt.h>
+#endif /* HAVE_GETOPT_LONG */
 
 extern void
 mix_vmloop (const gchar *code_file, gboolean use_emacs);
