@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mixvm_command.h :
  * Declarations for commands accepted by the mix virtual machine
  * ------------------------------------------------------------------
- * Copyright (C) 2000 jose antonio ortega ruiz <jaortega@acm.org>
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,13 +26,10 @@
 #include <glib.h>
 
 extern void
-mixvm_cmd_init (char *arg);
+mixvm_cmd_init (char *arg, gboolean use_emacs);
 
 extern gboolean
 mixvm_cmd_exec (char *line);
 
-
-
-
 #endif /* MIXVM_COMMAND_H */
 
